@@ -1,8 +1,8 @@
 import numpy as np
 import cv2 as cv
 
-class Vision:
 
+class Vision:
     # Attributes
     match_template_methods = None
     normalized_match_template_methods = None
@@ -54,14 +54,9 @@ class Vision:
         if debug_mode not in self.debug_modes:
             debug_mode = self.debug_modes[1]
 
-
         # Try to load images in memory using cv.imread()
-        try:
-            haystack_img = cv.imread(haystack_img_path)
-            needle_img = cv.imread(needle_img_path)
-        except BaseException as exception:
-            print('[VISION] Exception while loading images using cv.imread()')
-            print('[VISION] Exception info: ', exception)
+        haystack_img = cv.imread(haystack_img_path)
+        needle_img = cv.imread(needle_img_path)
 
         # Perform the matchTemplate function
         result_matrix = cv.matchTemplate(haystack_img, needle_img, method)
